==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/btron/WSDbtronAppDev.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDBTRONAPPDEV_H
#define WSDBTRONAPPDEV_H

//#include <X11/Intrinsic.h>
#include <btron/libapp.h>
#include <WSDappDev.h>
#define F_MEMGID

class WSDbtronFormDev;

class WSDbtronAppDev               :public WSDappDev {

  private:
#if 0
     Display*     _disp;
     XtAppContext _app_context;
     Widget       _app_widget;
     XEvent*      _ev;
     GC           _gc;
     GC           _gc2;
     Atom         _accept_atom_for_sock;
     Atom         _read_event_for_execute;
#endif
    W _gid;
    W _fgid;
    CSPEC _cspec;
    DEV_SPEC _dev_spec;
    WSCbool _have_color_map;
    COLOR* _color_map;
  protected:
//     WINFOREC* wlist;
  public:
     WSDbtronAppDev();
     virtual ~WSDbtronAppDev();

     virtual void update();

//     void setXEvent(XEvent*);
//     XEvent* getEvent();

     long setInitPrm(int, char**);
virtual long handleEvents();
virtual long dispatchEvent();
virtual long processEvent();
        long _dispatchEvent(WSCbool wait);
virtual long initialize();

//    void addWindow(W);
//    void delWindow(W);

#if 0
Display*       display();
Widget         appWidget();
XtAppContext   appContext();
GC             appGC();
GC             appGC2();
#endif

virtual long     getDeviceResource();
virtual long     getWindowResource();
virtual long     getContextResource();
virtual long     getSpecialResource();

virtual WSCushort getWidth();
virtual WSCushort getHeight();

    virtual long loadGuiPolicy();
    virtual long saveGuiPolicy();

    void setGid(W);
    WSCbool getGidInitialized();
    W getFontGid();
    DEV_SPEC* getDevSpec();
    CSPEC* getCSpec();
    WSCbool haveColorMap();
    WSCbool getMouseGrabbed();
    GID getNewMemGid(WSCulong w,WSCulong h);
    void setGrabTarget(WSDbtronFormDev*);
    void setBtnPressGrabTarget(WSDbtronFormDev*);
    WSDbtronFormDev* getGrabTarget();
    WSDbtronFormDev* getBtnPressGrabTarget();
//----------------------------------------------//
     WSMFclassDef(WSDbtronAppDev,WSDappDev);
};
extern WSDbtronAppDev* WSGIbtronAppDev();

extern void WSGFsetRect(RECT*,short,short,WSCushort,WSCushort);

#endif

==> ws-v3.80.2-src.tar.gz: ws-v3.80-2/include/btron/WSDbtronAppDev.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDBTRONAPPDEV_H
#define WSDBTRONAPPDEV_H

//#include <X11/Intrinsic.h>
#include <btron/libapp.h>
#include <WSDappDev.h>
#define F_MEMGID

class WSDbtronFormDev;

class WSDbtronAppDev               :public WSDappDev {

  private:
#if 0
     Display*     _disp;
     XtAppContext _app_context;
     Widget       _app_widget;
     XEvent*      _ev;
     GC           _gc;
     GC           _gc2;
     Atom         _accept_atom_for_sock;
     Atom         _read_event_for_execute;
#endif
    W _gid;
    W _fgid;
    CSPEC _cspec;
    DEV_SPEC _dev_spec;
    WSCbool _have_color_map;
    COLOR* _color_map;
    UB* _fgid_buf;
  protected:
//     WINFOREC* wlist;
  public:
     WSDbtronAppDev();
     virtual ~WSDbtronAppDev();

     virtual void update();

//     void setXEvent(XEvent*);
//     XEvent* getEvent();

     long setInitPrm(int, char**);
virtual long handleEvents();
virtual long dispatchEvent();
virtual long processEvent();
        long _dispatchEvent(WSCbool wait);
virtual long initialize();

//    void addWindow(W);
//    void delWindow(W);

#if 0
Display*       display();
Widget         appWidget();
XtAppContext   appContext();
GC             appGC();
GC             appGC2();
#endif

virtual long     getDeviceResource();
virtual long     getWindowResource();
virtual long     getContextResource();
virtual long     getSpecialResource();

virtual WSCushort getWidth();
virtual WSCushort getHeight();

    virtual long loadGuiPolicy();
    virtual long saveGuiPolicy();

    void setGid(W);
    WSCbool getGidInitialized();
    W getFontGid();
    DEV_SPEC* getDevSpec();
    CSPEC* getCSpec();
    WSCbool haveColorMap();
    WSCbool getMouseGrabbed();
    GID getNewMemGid(WSCulong w,WSCulong h,UB** buf);
    void setGrabTarget(WSDbtronFormDev*);
    void setBtnPressGrabTarget(WSDbtronFormDev*);
    WSDbtronFormDev* getGrabTarget();
    WSDbtronFormDev* getBtnPressGrabTarget();
//----------------------------------------------//
     WSMFclassDef(WSDbtronAppDev,WSDappDev);
};
extern WSDbtronAppDev* WSGIbtronAppDev();

extern void WSGFsetRect(RECT*,short,short,WSCushort,WSCushort);

#endif
